@@ -1,15 +1,19 @@
 #![cfg_attr(not(doctest), doc = include_str!("../README.md") )]
+
 #![feature(once_cell)]
 #![warn(missing_docs)]
+
 #![deny(rustdoc::broken_intra_doc_links)]
+
 #![warn(clippy::pedantic)]
+#![allow(clippy::must_use_candidate)]
 
 /// Definition of the [`Id`] struct.
 pub mod identity;
 /// Definition of the [`Scope`] trait.
 pub mod scope;
 
-pub use identity::{GlobalId, Id};
+pub use identity::{GlobalId, Id, IdHandle};
 pub use scope::{GlobalScope, Scope};
 
 #[cfg(feature = "derive")]
